@@ -8,19 +8,19 @@
  */
 // Used to set Application in caseinline=APP
 function setApplSpan(spanZ) {
-    var module = getParameterByName("DbPAR");
+    let module = getParameterByName("DbPAR");
     if (module === null) {
-        module = "WRITER";
+        module = "SHARED";
     }
-    var y = spanZ.getElementsByTagName("SPAN");
-    var n = y.length;
-    var foundAppl = false;
+    let y = spanZ.getElementsByTagName("SPAN");
+    let n = y.length;
+    let foundAppl = false;
     for (i = 0; i < n; i++) {
         if (y[i].getAttribute("id") === null){
             continue;
         }
         else if( y[i].getAttribute("id").startsWith(module)){
-            y[i].removeAttribute("hidden");
+            y[i].hidden = false;
             foundAppl=true;
         }
     }
@@ -29,8 +29,9 @@ function setApplSpan(spanZ) {
             continue;
         }
         else if( y[i].getAttribute("id").startsWith("default")){
+            y[i].hidden = true;
             if(!foundAppl){
-                y[i].removeAttribute("hidden");
+                y[i].hidden = false;
             }
         }
     }
@@ -38,63 +39,36 @@ function setApplSpan(spanZ) {
 // Used to set system in case, caseinline=SYSTEM
 function setSystemSpan(spanZ) {
     // if no System in URL, get browser system
-    var system = getParameterByName("System");
+    let system = getParameterByName("System");
     if (system === null) {
         system = getSystem();
     }
-    var y = spanZ.getElementsByTagName("SPAN");
-    var n = y.length;
-    var foundSystem = false;
-    for (i = 0; i < n; i++) {
+    let y = spanZ.getElementsByTagName("SPAN");
+    let n = y.length;
+    let foundSystem = false;
+
+    for (let i = 0; i < n; i++) {
         if (y[i].getAttribute("id") === null){
             continue;
         }
         else if( y[i].getAttribute("id").startsWith(system)){
-            y[i].removeAttribute("hidden");
+            y[i].hidden = false;
             foundSystem=true;
         }
     }
-    for (i = 0; i < n; i++) {
+    for (let i = 0; i < n; i++) {
         if (y[i].getAttribute("id") === null){
             continue;
         }
         else if( y[i].getAttribute("id").startsWith("default")){
+            y[i].hidden = true;
             if(!foundSystem){
-                y[i].removeAttribute("hidden");
+                y[i].hidden = false;
             }
         }
     }
 }
 
-// paint headers and headings with appl color
-
-function moduleColor (module) {
-    switch (module){
-        case "WRITER" : {color="#083fa6"; break;}
-        case "CALC"   : {color="#007c3c"; break;}
-        case "CHART"  : {color="darkcyan"; break;}
-        case "IMPRESS": {color="#d0120d"; break;}
-        case "DRAW"   : {color="#cb6d30"; break;}
-        case "BASE"   : {color="#7324a9"; break;}
-        case "BASIC"  : {color="black"; break;}
-        case "MATH"   : {color="#c10018"; break;}
-        case "SHARED" : {color="darkslategray"; break;}
-        default : {color="#18A303"; break;}
-    }
-    document.getElementById("TopLeftHeader").style.background = color;
-    document.getElementById("SearchFrame").style.background = color;
-    document.getElementById("DonationFrame").style.background = color;
-    var cols = document.getElementsByClassName('tableheadcell');
-    for(i = 0; i < cols.length; i++) {cols[i].style.backgroundColor = color;};
-    for (j of [1,2,3,4,5,6]) {
-        var hh = document.getElementsByTagName("H" + j);
-        for(i = 0; i < hh.length; i++) {
-            hh[i].style.color = color;
-            hh[i].style.borderBottomColor = color;
-        }
-    }
-}
-
 /* add &DbPAR= and &System= to the links in DisplayArea div */
 /* skip for object files */
 function fixURL(module, system) {
@@ -232,7 +206,6 @@ let system = getParameterByName("System");
 let helpID = getParameterByName("HID");
 impl_Switches();
 fixURL(module,system);
-moduleColor(module);
 // only used in xhp pages with <help-id-missing/> tags
 let missingElement = document.getElementById("bm_HID2");
 if(missingElement != null){missingElement.innerHTML = helpID;}
